---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:legge:1988-08-23;400
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=19880912&codiceRedaz=088G0458&dataVigenza=20251104
dataGU: 19880912
codiceRedaz: 088G0458
dataVigenza: 20251104
---

# Disciplina dell'attivita' di Governo e ordinamento della
Presidenza del Consiglio dei Ministri.

La Camera dei deputati ed il Senato della Repubblica hanno approvato;

IL PRESIDENTE DELLA REPUBBLICA

PROMULGA la seguente legge:

## GLI ORGANI DEL GOVERNO

### Art. 1. - (Gli organi del Governo Formula di giuramento)

1. Il Governo della Repubblica e' composto del Presidente del Consiglio dei ministri e dei ministri, che costituiscono insieme il Consiglio dei ministri.

2. Il decreto di nomina del Presidente del Consiglio dei ministri e' da lui controfirmato, insieme ai decreti di accettazione delle dimissioni del precedente Governo.

3. Il Presidente del Consiglio dei ministri e i ministri, prima di assumere le funzioni, prestano giuramento nelle mani del Presidente della Repubblica con la seguente formula: "Giuro di essere fedele alla Repubblica, di osservare lealmente la Costituzione e le leggi e di esercitare le mie funzioni nell'interesse esclusivo della nazione".

### Art. 2. - (Attribuzioni del Consiglio dei ministri)

1. Il Consiglio dei ministri determina la politica generale del Governo e, ai fini dell'attuazione di essa, l'indirizzo generale dell'azione amministrativa; delibera altresi' su ogni questione relativa all'indirizzo politico fissato dal rapporto fiduciario con le Camere. Dirime i conflitti di attribuzione tra i ministri.

2. Il Consiglio dei ministri esprime l'assenso alla iniziativa del Presidente del Consiglio dei ministri di porre la questione di fiducia dinanzi alle Camere.

3. Sono sottoposti alla deliberazione del Consiglio dei ministri:

- a) le dichiarazioni relative all'indirizzo politico, agli impegni programmatici ed alle questioni su cui il Governo chiede la fiducia del Parlamento;
- b) i disegni di legge e le proposte di ritiro dei disegni di legge gia' presentati al Parlamento;
- c) i decreti aventi valore o forma di legge e i regolamenti da emanare con decreto del Presidente della Repubblica;
- d) gli atti di sua competenza previsti dall'articolo 127 della Costituzione e dagli statuti regionali speciali in ordine alle leggi regionali e delle provincie autonome di Trento e Bolzano, salvo quanto stabilito dagli statuti speciali per la regione siciliana e per la regione Valle d'Aosta; (5)
- e) le direttive da impartire tramite il commissario del Governo per l'esercizio delle funzioni amministrative delegate alle regioni che sono tenute ad osservarle;
- f) le proposte che il ministro competente formula per disporre il compimento degli atti in sostituzione dell'amministrazione regionale, in caso di persistente inattivita' degli organi nell'esercizio delle funzioni delegate, qualora tali attivita' comportino adempimenti da svolgersi entro i termini perentori previsti della legge o risultanti dalla natura degli interventi;
- g) le proposte di sollevare conflitti di attribuzione o di resistere nei confronti degli altri poteri dello Stato, delle regioni e delle provincie autonome;
- h) le linee di indirizzo in tema di politica internazionale e comunitaria e i progetti dei trattati e degli accordi internazionali, comunque denominati, di natura politica o militare;
- i) gli atti concernenti i rapporti tra lo Stato e la Chiesa cattolica di cui all'articolo 7 della Costituzione;
- l) gli atti concernenti i rapporti previsti dall'articolo 8 della Costituzione;
- m) i provvedimenti da emanare con decreto del Presidente della Repubblica previo parere del Consiglio di Stato, se il ministro competente non intende conformarsi a tale parere;
- n) la richiesta motivata di registrazione della Corte dei conti ai sensi dell'articolo 25 del regio decreto 12 luglio 1934, n. 1214;
- o) le proposte motivate per lo scioglimento dei consigli regionali;
- p) le determinazioni concernenti l'annullamento straordinario a tutela dell'unita' dell'ordinamento, degli atti amministrativi illegittimi, previo parere del Consiglio di Stato e, nei soli casi di annullamento di atti amministrativi delle regioni e delle province autonome, anche della Commissione parlamentare per le questioni regionali; (1)
- q) gli altri provvedimenti per i quali sia prescritta o il Presidente del Consiglio dei ministri ritenga opportuna la deliberazione consiliare.

((4. L'individuazione degli atti da sottoporre alla deliberazione del Consiglio dei Ministri e' tassativa, anche agli effetti dell'articolo 3, comma 1, della legge 15 gennaio 1994, n. 20.))

------------- AGGIORNAMENTO (1) La Corte costituzionale con sentenza 13-21 aprile 1989, n. 229 (in G.U. 1a s.s. 26/04/1989, n. 17) ha dichiarato l'illegittimita' costituzionale del terzo comma, lettera p) del presente articolo "nella parte in cui prevede l'adozione da parte del Consiglio dei ministri delle determinazioni concernenti l'annullamento straordinario degli atti amministrativi illegittimi delle Regioni e delle Province autonome". ------------- AGGIORNAMENTO (5) Successivamente la Corte Costituzionale, con sentenza 10 - 14 dicembre 1998, n. 408 (in G.U. 1a s.s. 16/12/1998, n. 50), ha dichiarato l'illegittimita' costituzionale dell'art. 8, comma 5, lettera c), della legge 15 marzo 1997, n. 59 (che ha abrogato le parole "gli atti di indirizzo e coordinamento dell'attivita' amministrativa delle regioni e, nel rispetto delle disposizioni statutarie, delle regioni a statuto speciale e delle province autonome di Trento e Bolzano" dell'articolo 2, comma 3, lettera d), della presente legge).

### Art. 3. - (Nomine alla presidenza di enti, istituti o aziende di competenza dell'amministrazione statale)

1. Le nomine alla presidenza di enti, istituti o aziende di carattere nazionale, di competenza dell'amministrazione statale, fatta eccezione per le nomine relative agli enti pubblici creditizi, sono effettuate con decreto del Presidente della Repubblica emanato su proposta del Presidente del Consiglio dei ministri, previa deliberazione del Consiglio dei ministri adottata su proposta del ministro competente.

2. Resta ferma la vigente disciplina in ordine all'acquisizione del parere delle competenti Commissioni parlamentari.

### Art. 4. - (Convocazione, sedute e regolamento interno del Consiglio dei ministri)

1. Il Consiglio dei ministri e' convocato dal Presidente del Consiglio dei ministri, che ne fissa l'ordine del giorno.

2. Il sottosegretario di Stato alla Presidenza del Consiglio dei ministri, designato nel decreto di nomina, e' il segretario del Consiglio ed esercita le relative funzioni; cura la verbalizzazione e la conservazione del registro delle deliberazioni.

3. Il regolamento interno disciplina gli adempimenti necessari per l'iscrizione delle proposte di iniziativa legislativa e di quelle relative all'attivita' normativa del Governo all'ordine del giorno del Consiglio dei ministri; i modi di comunicazione dell'ordine del giorno e della relativa documentazione ai Partecipanti alle riunioni del Consiglio dei ministri; i modi di verbalizzazione, conservazione e conoscenza delle deliberazioni adottate; le modalita' di informazione sui lavori del Consiglio.

4. Il regolamento interno del Consiglio dei ministri e' emanato con decreto del Presidente del Consiglio dei ministri, previa deliberazione del Consiglio dei ministri, ed e' pubblicato nella Gazzetta Ufficiale.

### Art. 5. - (Attribuzioni del Presidente del Consiglio dei ministri)

1. Il Presidente del Consiglio dei ministri a nome del Governo:

- a) comunica alle Camere la composizione del Governo e ogni mutamento in essa intervenuto;
- b) chiede la fiducia sulle dichiarazioni di cui alla lettera a) del comma 3 dell'articolo 2 e pone, direttamente o a mezzo di un ministro espressamente delegato, la questione di fiducia;
- c) sottopone al Presidente della Repubblica le leggi per la promulgazione; in seguito alla deliberazione del Consiglio dei ministri, i disegni di legge per la presentazione alla Camere e, per l'emanazione, i testi dei decreti aventi valore o forza di legge, dei regolamenti governativi e degli altri atti indicati dalle leggi;
- d) controfirma gli atti di promulgazione delle leggi nonche' ogni atto per il quale e' intervenuta deliberazione del Consiglio dei ministri, gli atti che hanno valore o forza di legge e, insieme con il ministro proponente, gli altri atti indicati dalla legge;
- e) presenta alle Camere i disegni di legge di iniziativa governativa e, anche attraverso il ministro espressamente delegato, esercita le facolta' del Governo di cui all'articolo 72 della Costituzione;
- f) esercita le attribuzioni di cui alla legge 11 marzo 1953, n. 87, e promuovere gli adempimenti di competenza governativa conseguenti alle decisioni della Corte costituzionale. Riferisce inoltre periodicamente al Consiglio dei ministri, e ne da' comunicazione alle Camere, sullo stato del contenzioso costituzionale, illustrando le linee seguite nelle determinazioni relative agli interventi nei giudizi dinanzi alla Corte costituzionale. Segnala altresi', anche su proposta dei ministri competenti, i settori della legislazione nei quali, in relazione alle questioni di legittimita' costituzionale pendenti, sia utile valutare l'opportunita' di iniziative legislative del Governo.

2. Il Presidente del Consiglio dei ministri, ai sensi dell'articolo 95, primo comma, della Costituzione:

- a) indirizza ai ministri le direttive politiche ed amministrative in attuazione delle deliberazioni del Consiglio dei ministri nonche' quelle connesse alla propria responsabilita' di direzione della politica generale del Governo;
- b) coordina e promuove l'attivita' dei ministri in ordine agli atti che riguardano la politica generale del Governo;
- c) puo' sospendere l'adozione di atti da parte dei ministri competenti in ordine a questioni politiche e amministrative, sottoponendoli al Consiglio dei ministri nella riunione immediatamente successiva;
- c-bis) puo' deferire al Consiglio dei Ministri, ai fini di una complessiva valutazione ed armonizzazione degli interessi pubblici coinvolti, la decisione di questioni sulle quali siano emerse valutazioni contrastanti tra amministrazioni a diverso titolo competenti in ordine alla definizione di atti e provvedimenti;
- d) concorda con i ministri interessati le pubbliche dichiarazioni che essi intendano rendere ogni qualvolta eccedendo la normale responsabilita' ministeriale, possano impegnare la politica generale del Governo;
- e) adotta le direttive per assicurare l'imparzialita', il buon andamento e l'efficienza degli uffici pubblici e promuove le verifiche necessarie; in casi di particolare rilevanza puo' richiedere al ministro competente relazioni e verifiche amministrative;
- f) promuove l'azione dei ministri per assicurare che le aziende e gli enti pubblici svolgano la loro attivita' secondo gli obiettivi indicati dalle leggi che ne definiscono l'autonomia e in coerenza con i conseguenti indirizzi politici e amministrativi del Governo;
- g) esercita le attribuzioni conferitegli dalla legge in materia di servizi di sicurezza e di segreto di Stato;
- h) puo' disporre, con proprio decreto, l'istituzione di particolari Comitati di ministri, con il compito di esaminare in via preliminare questioni di comune competenza, di esprimere parere su direttive dell'attivita' del Governo e su problemi di rilevante importanza da sottoporre al Consiglio dei ministri, eventualmente anche di esperti non appartenenti alla pubblica amministrazione;
- i) puo' disporre la costituzione di gruppi di studio e di lavoro composti in modo da assicurare la presenza di tutte le competenze dicasteriali interessate ed eventualmente di esperti anche non appartenenti alla pubblica amministrazione.

3. Il Presidente del Consiglio dei ministri, direttamente o conferendone delega ad un ministro:

- a) promuove e coordina l'azione del Governo relativa alle politiche comunitarie e assicura la coerenza e la tempestivita' dell'azione di Governo e della pubblica amministrazione nell'attuazione delle politiche comunitarie, riferendone periodicamente alle Camere; promuovere gli adempimenti di competenza governativa conseguenti alle pronunce della Corte di giustizia delle Comunita' europee; cura la tempestiva comunicazione alle Camere dei procedimenti normativi in corso nelle Comunita' europee, informando il Parlamento delle iniziative e posizioni assunte dal Governo nelle specifiche materie;
- a-bis) promuove gli adempimenti di competenza governativa conseguenti alle pronunce della Corte europea dei diritti dell'uomo emanate nei confronti dello Stato italiano; comunica tempestivamente alle Camere le medisime pronunce ai fini dell'esame da parte delle competenti Commissioni parlamentari permanenti e presenta annualmente al Parlamento una relazione sullo stato di esecuzione delle suddette pronunce;
- b) promuovere e coordina l'azione del Governo per quanto attiene ai rapporti con le regioni e le province autonome di Trento e di Bolzano e sovraintende all'attivita' dei commissari del Governo;
- b-bis) promuove, indirizza, coordina l'azione del Governo nelle materie dell'innovazione tecnologica, dell'attuazione dell'agenda digitale italiana ed europea, della strategia italiana per la banda ((ultralarga)), della digitalizzazione delle pubbliche amministrazioni e delle imprese, nonche' della trasformazione, crescita e transizione digitale del Paese, in ambito pubblico e privato, dell'accesso ai servizi in rete, della connettivita', delle infrastrutture digitali materiali e immateriali e della strategia nazionale dei dati pubblici.

4. Il Presidente del Consiglio dei ministri esercita le altre attribuzioni conferitegli dalla legge.

### Art. 6. - (Consiglio di Gabinetto, Comitati di ministri e Comitati interministeriali)

1. Il Presidente del Consiglio dei ministri, nello svolgimento delle funzioni previste dall'articolo 95, primo comma, della Costituzione, puo' essere coadiuvato da un Comitato, che prende nome di Consiglio di Gabinetto, ed e' composto dai ministri da lui designati, sentito il Consiglio dei ministri.

2. Il Presidente del Consiglio dei ministri puo' invitare a singole sedute del Consiglio di Gabinetto altri ministri in ragione della loro competenza.

3. I Comitati di ministri e quelli interministeriali istituiti per legge debbono tempestivamente comunicare al Presidente del Consiglio dei ministri l'ordine del giorno delle riunioni. Il Presidente del Consiglio dei ministri puo' deferire singole questioni al Consiglio dei ministri, perche' stabilisca le direttive alle quali i Comitati debbono attenersi, nell'ambito delle norme vigenti.

### Art. 7. - (Delega per il riordinamento dei Comitati di ministri e dei Comitati interministeriali)

1. Il Governo e' delegato ad emanare, entro un anno dalla data di entrata in vigore della presente legge, norme aventi valore di legge ordinaria intese a ridurre e riordinare i Comitati di ministri, compresi quelli non istituiti con legge, ed i Comitati interministeriali previsti dalle leggi vigenti, ad eccezione del Comitato interministeriale per il credito e il risparmio, anche in relazione alle norme, agli strumenti ed alle procedure disciplinate nella presente legge, secondo i seguenti principi e criteri direttivi:

- a) eliminazione di duplicazioni e sovrapposizioni di competenze;
- b) coordinamento delle attivita' inerenti a settori omogenei di competenza anche se ripartiti fra piu' Ministeri.

2. I decreti delegati di cui al comma 1 sono emanati previo parere delle Commissioni permanenti delle Camere competenti per materia. Il Governo procede comunque alla emanazione dei decreti delegati qualora tale parere non sia espresso entro trenta giorni dalla richiesta.

3. Con decreto del Presidente della Repubblica, su proposta del Presidente del Consiglio dei ministri, previa deliberazione del Consiglio dei ministri, si provvede ad adottare norme regolamentari volte a garantire procedure uniformi in ordine alla convocazione, alla fissazione dell'ordine del giorno, al numero legale, alle decisioni e alle forme di conoscenza delle attivita' dei comitati. ((2))

------------- AGGIORNAMENTO (2) Il D.L. 30 giugno 1989, n. 245, convertito con modificazioni dalla L. 4 agosto 1989, n. 288, ha disposto (con l'art. 6-ter, comma 4) che il termine per l'esercizio della delega di cui al presente articolo e' prorogato al 31 dicembre 1989.

### Art. 8. - (Vicepresidenti del Consiglio dei ministri)

1. Il Presidente del Consiglio dei ministri puo' proporre al Consiglio dei ministri l'attribuzione ad uno o piu' ministri delle funzioni di Vicepresidente del Consiglio dei ministri. Ricorrendo questa ipotesi, in caso di assenza o impedimento temporaneo del Presidente del Consiglio dei ministri, la supplenza spetta al Vicepresidente o, qualora siano nominati piu' Vicepresidenti, al Vicepresidente piu' anziano secondo l'eta'.

2. Quando non sia stato nominato il Vicepresidente del Consiglio dei ministri, la supplenza di cui al comma 1 spetta, in assenza di diversa disposizione da parte del Presidente del Consiglio dei ministri, al ministro piu' anziano secondo l'eta'.

### Art. 9. - Ministri senza portafoglio, incarichi speciali di Governo, incarichi di reggenza ad interim

1. All'atto della costituzione del Governo, il Presidente della Repubblica, su proposta del Presidente del Consiglio dei ministri, puo' nominare, presso la Presidenza del Consiglio dei ministri, ministri senza portafoglio, i quali svolgono le funzioni loro delegate dal Presidente del Consiglio dei ministri sentito il Consiglio dei ministri, con provvedimento da pubblicarsi nella Gazzetta Ufficiale. ((14))

2. Ogni qualvolta la legge o altra fonte normativa assegni, anche in via delegata, compiti specifici ad un Ministro senza portafoglio ovvero a specifici uffici o dipartimenti della Presidenza del Consiglio dei ministri, gli stessi si intendono comunque attribuiti, rispettivamente, al Presidente del Consiglio dei ministri, che puo' delegarli a un Ministro o a un Sottosegretario di Stato, e alla Presidenza del Consiglio dei Ministri.

3. Il Presidente del Consiglio dei ministri, sentito il Consiglio dei ministri, puo' conferire ai ministri, con decreto di cui e' data notizia nella Gazzetta Ufficiale, incarichi speciali di Governo per un tempo determinato.

4. Il Presidente della Repubblica su proposta del Consiglio dei ministri, puo' conferire al Presidente del Consiglio stesso o ad un ministro l'incarico di reggere ad interim un Dicastero, con decreto di cui e' data notizia nella Gazzetta Ufficiale.

------------- AGGIORNAMENTO (14) La L. 3 agosto 2007, n. 124 ha disposto (con l'art. 3, comma 4) che "In deroga a quanto previsto dal comma 1 dell'articolo 9 della legge 23 agosto 1988, n. 400, e successive modificazioni, non e' richiesto il parere del Consiglio dei ministri per il conferimento delle deleghe di cui al presente articolo al Ministro senza portafoglio."

### Art. 10. - (Sottosegretari di Stato)

1. I Sottosegretari di Stato sono nominati con decreto del Presidente della Repubblica, su proposta del Presidente del Consiglio dei ministri, di concerto con il ministro che il sottosegretario e' chiamato a coadiuvare, sentito il Consiglio dei ministri.

2. Prima di assumere le funzioni i sottosegretari di Stato prestano giuramento nelle mani del Presidente del Consiglio dei ministri con la formula di cui all'articolo 1.

3. I sottosegretari di stato coadiuvano il ministro ed esercitano i compiti ad essi delegati con decreto ministeriale pubblicato nella Gazzetta Ufficiale. Fermi restando la responsabilita' politica e i poteri di indirizzo politico dei Ministri ai sensi dell'articolo 95 della Costituzione, a non piu' di dieci Sottosegretari puo' essere attribuito il titolo di vice ministro, se ad essi sono conferite deleghe relative ((ad aree o progetti di competenza)) di una o piu' strutture dipartimentali ovvero di piu' direzioni generali. In tale caso la delega, conferita dal Ministro competente, e' approvata dal Consiglio dei Ministri, su proposta del Presidente del Consiglio dei Ministri.

4. I sottosegretari di Stato possono intervenire, quali rappresentanti del Governo, alle sedute delle Camere e delle Commissioni parlamentari, sostenere la discussione in conformita' alle direttive del ministro e rispondere ad interrogazioni ed interpellanze. I vice ministri di cui al comma 3 possono essere invitati dal Presidente del Consiglio dei Ministri, d'intesa con il Ministro competente, a partecipare alle sedute del Consiglio dei Ministri, senza diritto di voto, per riferire su argomenti e questioni attinenti alla materia loro delegata.

5. Oltre al sottosegretario di Stato nominato segretario del Consiglio dei ministri, possono essere nominati presso la Presidenza del Consiglio dei ministri altri sottosegretari per lo svolgimento di determinati compiti e servizi. La legge sull'organizzazione dei Ministeri determina il numero e le attribuzioni dei sottosegretari. Entro tali limiti i sottosegretari sono assegnati alla Presidenza del Consiglio dei ministri ed ai Ministeri.

### Art. 11. - (Commissari straordinari del Governo)

1. Al fine di realizzare specifici obiettivi determinati in relazione a programmi o indirizzi deliberati dal Parlamento o dal Consiglio dei ministri o per particolari e temporanee esigenze di coordinamento operativo tra amministrazioni statali, puo' procedersi alla nomina di commissari straordinari del Governo, ferme restando le attribuzioni dei Ministeri, fissate per legge.

2. La nomina e' disposta con decreto del Presidente della Repubblica, su proposta del Presidente del Consiglio dei ministri, previa deliberazione del Consiglio dei ministri. Con il medesimo decreto sono determinati i compiti del commissario e le dotazioni di mezzi e di personale. L'incarico e' conferito per il tempo indicato nel decreto di nomina, salvo proroga o revoca. Del conferimento dell'incarico e' data immediata comunicazione al Parlamento e notizia nella Gazzetta Ufficiale.

3. Sull'attivita' del commissario straordinario riferisce al Parlamento il Presidente del Consiglio dei ministri o un ministro da lui delegato. ((15))

------------- AGGIORNAMENTO (15) La L. 24 dicembre 2007, n. 244, ha disposto (con l'art. 1, comma 378) che "I compensi dei Commissari straordinari di Governo, di cui all'articolo 11 della legge 23 agosto 1988, n. 400, sono ridotti del 20 per cento dal 1° gennaio 2008".

## RAPPORTI TRA LO STATO, LE REGIONI E LE PROVINCIE AUTONOME

### Art. 12. - (Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome)

1. E' istituita, presso la Presidenza del Consiglio dei ministri, la Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano, con compiti di informazione, consultazione e raccordo, in relazione agli indirizzi di politica generale suscettibili di incidere nelle materie di competenza regionale, esclusi gli indirizzi generali relativi alla politica estera, alla difesa e alla sicurezza nazionale, alla giustizia.

2. La Conferenza e' convocata dal Presidente del Consiglio dei ministri almeno ogni sei mesi, ed in ogni altra circostanza in cui il Presidente lo ritenga opportuno, tenuto conto anche delle richieste dei presidenti delle regioni e delle province autonome. Il Presidente del Consiglio dei ministri presiede la Conferenza, salvo delega al ministro per gli affari regionali o, se tale incarico non e' attribuito, ad altro ministro. La Conferenza e' composta dai presidenti delle regioni a statuto speciale e ordinario e dai presidenti delle province autonome. Il Presidente del Consiglio dei ministri invita alle riunioni della Conferenza i ministri interessati agli argomenti iscritti all'ordine del giorno, nonche' rappresentanti di amministrazioni dello Stato o di enti pubblici.

3. La Conferenza dispone di una segreteria, disciplinata con decreto del Presidente del Consiglio dei ministri, di concerto con il ministro per gli affari regionali.

4. Il decreto di cui al comma 3 deve prevedere l'inclusione nel contingente della segreteria di personale delle regioni o delle province autonome, il cui trattamento economico resta a carico delle regioni o delle province di provenienza.

5. La Conferenza viene consultata:

- a) sulle linee generali dell'attivita' normativa che interessa direttamente le regioni e sulla determinazione degli obiettivi di programmazione economica nazionale e della politica finanziaria e di bilancio, salve le ulteriori attribuzioni previste in base al comma 7 del presente articolo;
- b) sui criteri generali relativi all'esercizio delle funzioni statali di indirizzo e di coordinamento inerenti ai rapporti tra lo Stato, le regioni, le province autonome e gli enti infraregionali, nonche' sugli indirizzi generali relativi alla elaborazione ed attuazione degli atti comunitari che riguardano le competenze regionali;
- c) sugli altri argomenti per i quali il Presidente del Consiglio dei ministri ritenga opportuno acquisire il parere della Conferenza.

6. Il Presidente del Consiglio dei ministri, o il ministro appositamente delegato, riferisce periodicamente alla Commissione parlamentare per le questioni regionali sulle attivita' della Conferenza.

7. Il Governo e' delegato ad emanare, entro un anno dalla data di entrata in vigore della presente legge, previo parere della Commissione parlamentare per le questioni regionali che deve esprimerlo entro sessanta giorni dalla data richiesta, norme aventi valore di legge ordinaria intese a provvedere al riordino ed alla eventuale soppressione degli altri organismi a composizione mista Stato-regioni previsti sia da leggi che da provvedimenti amministrativi in modo da trasferire alla Conferenza le attribuzioni delle commissioni, con esclusioni di quelle che operano sulla base di competenze tecnico-scientifiche, e rivedere la pronuncia di pareri nelle questioni di carattere generale per le quali debbano anche essere sentite tutte le regioni e province autonome, determinando le modalita' per l'acquisizione di tali pareri, per la cui formazione possono votare solo i presidenti delle regioni e delle province autonome. ((2))

------------- AGGIORNAMENTO (2) Il D.L. 30 giugno 1989, n. 245, convertito con modificazioni dalla L. 4 agosto 1989, n. 288, ha disposto (con l'art. 6-ter, comma 3) che il termine per l'esercizio della delega di cui al comma 7 del presente articolo e' prorogato fino al 31 dicembre 1989.

### Art. 13. - (Commissario del Governo)

1. ((COMMA ABROGATO DALLA L. 5 GIUGNO 2003, N. 131)).

2. ((COMMA ABROGATO DALLA L. 5 GIUGNO 2003, N. 131)).

3. Per la regione siciliana e per la regione Valle d'Aosta il coordinamento dei programmi degli interventi statali e regionali, nel rispetto di quanto previsto dagli Statuti speciali, viene disciplinato dalle norme di attuazione, che dovranno prevedere apposite forme di intesa. Per la regione autonoma della Valle d'Aosta restano ferme le disposizioni contenute nel decreto legislativo luogotenenziale 7 settembre 1945, n. 545.

4. ((COMMA ABROGATO DALLA L. 5 GIUGNO 2003, N. 131)).

5. ((COMMA ABROGATO DALLA L. 5 GIUGNO 2003, N. 131)).

6. ((COMMA ABROGATO DALLA L. 5 GIUGNO 2003, N. 131)).

7. ((COMMA ABROGATO DALLA L. 5 GIUGNO 2003, N. 131)).

8. ((COMMA ABROGATO DALLA L. 5 GIUGNO 2003, N. 131)).

## POTESTA' NORMATIVA DEL GOVERNO

### Art. 13-bis.

(( (Chiarezza dei testi normativi). )) ((

1. Il Governo, nell'ambito delle proprie competenze, provvede a che:

- a) ogni norma che sia diretta a sostituire, modificare o abrogare norme vigenti ovvero a stabilire deroghe indichi espressamente le norme sostituite, modificate, abrogate o derogate;
- b) ogni rinvio ad altre norme contenuto in disposizioni legislative, nonche' in regolamenti, decreti o circolari emanati dalla pubblica amministrazione, contestualmente indichi, in forma integrale o in forma sintetica e di chiara comprensione, il testo ovvero la materia alla quale le disposizioni fanno riferimento o il principio, contenuto nelle norme cui si rinvia, che esse intendono richiamare.

2. Le disposizioni della presente legge in materia di chiarezza dei testi normativi costituiscono principi generali per la produzione normativa e non possono essere derogate, modificate o abrogate se non in modo esplicito.

3. Periodicamente, e comunque almeno ogni sette anni, si provvede all'aggiornamento dei codici e dei testi unici con i medesimi criteri e procedure previsti nell'articolo 17-bis adottando, nel corpo del testo aggiornato, le opportune evidenziazioni.

4. La Presidenza del Consiglio dei ministri adotta atti di indirizzo e coordinamento per assicurare che gli interventi normativi incidenti sulle materie oggetto di riordino, mediante l'adozione di codici e di testi unici, siano attuati esclusivamente mediante modifica o integrazione delle disposizioni contenute nei corrispondenti codici e testi unici)).

### Art. 14. - (Decreti legislativi)

1. I decreti legislativi adottati dal Governo ai sensi dell'articolo 76 della Costituzione sono emanati dal Presidente della Repubblica con la denominazione di "decreto legislativo" e con l'indicazione, nel preambolo, della legge di delegazione, della deliberazione del Consiglio dei ministri e degli altri adempimenti del procedimento prescritti dalla legge di delegazione.

2. L'emanazione del decreto legislativo deve avvenire entro il termine fissato dalla legge di delegazione; il testo del decreto legislativo adottato dal Governo e' trasmesso al Presidente della Repubblica, per la emanazione, almeno venti giorni prima della scadenza.

3. Se la delega legislativa si riferisce ad una pluralita' di oggetti distinti suscettibili di separata disciplina, il Governo puo' esercitarla mediante piu' atti successivi per uno o piu' degli oggetti predetti. In relazione al termine finale stabilito dalla legge di delegazione, il Governo informa periodicamente le Camere sui criteri che segue nell'organizzazione dell'esercizio della delega.

4. In ogni caso, qualora il termine previsto per l'esercizio della delega ecceda i due anni, il Governo e' tenuto a richiedere il parere delle Camere sugli schemi dei decreti delegati. Il parere e' espresso dalle Commissioni permanenti delle due Camere competenti per materia entro sessanta giorni, indicando specificamente le eventuali disposizioni non ritenute corrispondenti alle direttive della legge di delegazione. Il Governo, nei trenta giorni successivi, esaminato il parere, ritrasmette, con le sue osservazioni e con eventuali modificazioni, i testi alle Commissioni per il parere definitivo che deve essere espresso entro trenta giorni.

### Art. 15. - (Decreti-legge)

1. I provvedimenti provvisori con forza di legge ordinaria adottati ai sensi dell'articolo 77 della Costituzione sono presentati per l'emanazione al Presidente della Repubblica con la denominazione di "decreto-legge" e con l'indicazione, nel preambolo, delle circostanze straordinarie di necessita' e di urgenza che ne giustificano l'adozione, nonche' dell'avvenuta deliberazione del Consiglio dei ministri.

2. Il Governo non puo', mediante decreto-legge:

- a) conferire deleghe legislative ai sensi dell'articolo 76 della Costituzione;
- b) provvedere nelle materie indicate nell'articolo 72, quarto comma, della Costituzione;
- c) rinnovare le disposizioni di decreti-legge dei quali sia stata negata la conversione in legge con il voto di una delle due Camere;
- d) regolare i rapporti giuridici sorti sulla base dei decreti non convertiti;
- e) ripristinare l'efficacia di disposizioni dichiarate illegittime dalla Corte costituzionale per vizi non attinenti al procedimento:

3. I decreti devono contenere misure di immediata applicazione e il loro contenuto deve essere specifico, omogeneo e corrispondente al titolo.

4. Il decreto-legge e' pubblicato, senza ulteriori adempimenti, nella Gazzetta Ufficiale immediatamente dopo la sua emanazione e deve contenere la clausola di presentazione al Parlamento per la conversione in legge.

5. Le modifiche eventualmente apportate al decreto-legge in sede di conversione hanno efficacia dal giorno successivo a quello della pubblicazione della legge di conversione, salvo che quest'ultima non disponga diversamente. Esse sono elencate in allegato alla legge.

6. Il Ministro di grazia e giustizia cura che del rifiuto di conversione o della conversione parziale, purche' definitiva, nonche' della mancata conversione per decorrenza del termine sia data immediata pubblicazione nella Gazzetta Ufficiale.

### Art. 16. - (Atti aventi valore o forza di legge, Valutazione delle conseguenze finanziarie)

1. Non sono soggetti al controllo preventivo di legittimita' della Corte dei conti i decreti del Presidente della Repubblica, adottati su deliberazione del Consiglio dei ministri, ai sensi degli articoli 76 e 77 della Costituzione.

2. Il Presidente della Corte dei conti, in quanto ne faccia richiesta la Presidenza di una delle Camere, anche su iniziativa delle Commissioni parlamentari competenti, trasmette al Parlamento le valutazioni della Corte in ordine alle conseguenze finanziarie che deriverebbero dalla conversione in legge di un decreto-legge o dalla emanazione di un decreto legislativo adottato dal Governo su delegazione delle Camere.

### Art. 17. - (Regolamenti)

1. Con decreto del Presidente della Repubblica, previa deliberazione del Consiglio dei ministri, sentito il parere del Consiglio di Stato che deve pronunziarsi entro novanta giorni dalla richiesta, possono essere emanati regolamenti per disciplinare:

- a) l'esecuzione delle leggi e dei decreti legislativi nonche' dei regolamenti comunitari;
- b) l'attuazione e l'integrazione delle leggi e dei decreti legislativi recanti norme di principio, esclusi quelli relativi a materie riservate alla competenza regionale;
- c) le materie in cui manchi la disciplina da parte di leggi o di atti aventi forza di legge, sempre che non si tratti di materie comunque riservate alla legge;
- d) l'organizzazione ed il funzionamento delle amministrazioni pubbliche secondo le disposizioni dettate dalla legge;
- e) IL D.LGS. 30 MARZO 2001, N. 165 HA CONFERMATO L'ABROGAZIONE DELLA PRESENTE LETTERA.

2. Con decreto del Presidente della Repubblica, previa deliberazione del Consiglio dei ministri, sentito il Consiglio di Stato ((e previo parere delle Commissioni parlamentari competenti in materia, che si pronunciano entro trenta giorni dalla richiesta)), sono emanati i regolamenti per la disciplina delle materie, non coperte da riserva assoluta di legge prevista dalla Costituzione, per le quali le leggi della Repubblica, autorizzando l'esercizio della potesta' regolamentare del Governo, determinano le norme generali regolatrici della materia e dispongono l'abrogazione delle norme vigenti, con effetto dall'entrata in vigore delle norme regolamentari.

3. Con decreto ministeriale possono essere adottati regolamenti nelle materie di competenza del ministro o di autorita' sottordinate al ministro, quando la legge espressamente conferisca tale potere. Tali regolamenti, per materie di competenza di piu' ministri, possono essere adottati con decreti interministeriali, ferma restando la necessita' di apposita autorizzazione da parte della legge. I regolamenti ministeriali ed interministeriali non possono dettare norme contrarie a quelle dei regolamenti emanati dal Governo. Essi debbono essere comunicati al Presidente del Consiglio dei ministri prima della loro emanazione.

4. I regolamenti di cui al comma 1 ed i regolamenti ministeriali ed interministeriali, che devono recare la denominazione di "regolamento", sono adottati previo parere del Consiglio di Stato, sottoposti al visto ed alla registrazione della Corte dei conti e pubblicati nella Gazzetta Ufficiale.

4-bis. L'organizzazione e la disciplina degli uffici dei Ministeri sono determinate, con regolamenti emanati ai sensi del comma 2, su proposta del Ministro competente d'intesa con il Presidente del Consiglio dei ministri e con il Ministro del tesoro, nel rispetto dei principi posti dal decreto legislativo 3 febbraio 1993, n. 29, e successive modificazioni, con i contenuti e con l'osservanza dei criteri che seguono:

- a) riordino degli uffici di diretta collaborazione con i Ministri ed i Sottosegretari di Stato, stabilendo che tali uffici hanno esclusive competenze di supporto dell'organo di direzione politica e di raccordo tra questo e l'amministrazione;
- b) individuazione degli uffici di livello dirigenziale generale, centrali e periferici, mediante diversificazione tra strutture con funzioni finali e con funzioni strumentali e loro organizzazione per funzioni omogenee e secondo criteri di flessibilita' eliminando le duplicazioni funzionali;
- c) previsione di strumenti di verifica periodica dell'organizzazione e dei risultati;
- d) indicazione e revisione periodica della consistenza delle piante organiche;
- e) previsione di decreti ministeriali di natura non regolamentare per la definizione dei compiti delle unita' dirigenziali nell'ambito degli uffici dirigenziali generali.

((4-ter. Con regolamenti da emanare ai sensi del comma 1 del presente articolo, si provvede al periodico riordino delle disposizioni regolamentari vigenti, alla ricognizione di quelle che sono state oggetto di abrogazione implicita e all'espressa abrogazione di quelle che hanno esaurito la loro funzione o sono prive di effettivo contenuto normativo o sono comunque obsolete))

### Art. 17-bis.

(( (Testi unici compilativi). )) ((

1. Il Governo provvede, mediante testi unici compilativi, a raccogliere le disposizioni aventi forza di legge regolanti materie e settori omogenei, attenendosi ai seguenti criteri:

- a) puntuale individuazione del testo vigente delle norme;
- b) ricognizione delle norme abrogate, anche implicitamente, da successive disposizioni;
- c) coordinamento formale del testo delle disposizioni vigenti in modo da garantire la coerenza logica e sistematica della normativa;
- d) ricognizione delle disposizioni, non inserite nel testo unico, che restano comunque in vigore.

2. Lo schema di ciascun testo unico e' deliberato dal Consiglio dei ministri, valutato il parere che il Consiglio di Stato deve esprimere entro quarantacinque giorni dalla richiesta. Ciascun testo unico e' emanato con decreto del Presidente della Repubblica, su proposta del Presidente del Consiglio dei ministri, previa ulteriore deliberazione del Consiglio dei ministri.

3. Il Governo puo' demandare la redazione degli schemi di testi unici ai sensi dell'articolo 14, numero 2°, del testo unico delle leggi sul Consiglio di Stato, di cui al regio decreto 26 giugno 1924, n. 1054, al Consiglio di Stato, che ha facolta' di avvalersi di esperti, in discipline non giuridiche, in numero non superiore a cinque, nell'ambito dei propri ordinari stanziamenti di bilancio e, comunque, senza nuovi o maggiori oneri a carico del bilancio dello Stato. Sugli schemi redatti dal Consiglio di Stato non e' acquisito il parere dello stesso, previsto ai sensi dell'articolo 16, primo comma, numero 3°, del citato testo unico di cui al regio decreto n. 1054 del 1924, dell'articolo 17, comma 25, della legge 15 maggio 1997, n. 127, e del comma 2 del presente articolo)).

## ORGANIZZAZIONE AMMINISTRATIVA DELLA PRESIDENZA DEL CONSIGLIO DEI MINISTRI E RIORDINO DI TALUNE FUNZIONI

### Art. 18. - (Segretariato generale della Presidenza del Consiglio dei ministri)

1. ((COMMA ABROGATO DAL D.LGS. 30 LUGLIO 1999, N. 303)).

2. Al Segretariato e' preposto un segretario generale, nominato con decreto del Presidente del Consiglio dei ministri, tra i magistrati delle giurisdizioni superiori ordinaria ed amministrativa, gli avvocati dello Stato, i dirigenti generali dello Stato ed equiparati, i professori universitari di ruolo ovvero tra estranei alla pubblica amministrazione. ((PERIODO ABROGATO DAL D.LGS. 30 LUGLIO 1999, N. 303)). Il Presidente del Consiglio dei ministri puo', con proprio decreto, nominare altresi' il vicesegretario generale scelto tra le predette categorie. Con la medesima procedura puo' essere disposta la revoca del decreto di nomina del segretario generale e del vicesegretario generale.

3. I decreti di nomina del segretario generale, del vicesegretario generale, dei capi dei dipartimenti e degli uffici di cui all'articolo 21 cessano di avere efficacia dalla data del giuramento del nuovo Governo. Il segretario generale, il vicesegretario generale ed i capi dei dipartimenti e degli uffici di cui all'articolo 21, ove pubblici dipendenti e non appartenenti al ruolo della Presidenza del Consiglio dei ministri, sono collocati fuori ruolo nelle amministrazioni di provenienza. ((Sono del pari collocati obbligatoriamente fuori ruolo nelle amministrazioni di appartenenza, oltre agli esperti di cui all'articolo 3 della legge 8 marzo 1999, n. 50, i vice capi delle strutture che operano nelle aree funzionali relative al coordinamento dell'attivita' normativa ed amministrativa del Governo, al coordinamento degli affari economici, alla promozione dell'innovazione nel settore pubblico e coordinamento del lavoro pubblico, nonche' il dirigente generale della polizia di Stato preposto all'Ispettorato generale che e' adibito alla sicurezza del Presidente e delle sedi del Governo e che, per quanto attiene al suo speciale impiego, dipende funzionalmente dal Segretario generale.))

4. La funzione di capo dell'ufficio stampa puo' essere affidata ad un elemento estraneo all'amministrazione, il cui trattamento economico e' determinato in conformita' a quello dei dirigenti generali dello Stato.

5. ((COMMA ABROGATO DAL D.LGS. 30 LUGLIO 1999 N. 303)).

### Art. 19. - (Compiti del Segretariato generale della Presidenza del Consiglio dei ministri)

1. Il Segretariato generale della Presidenza del Consiglio dei ministri assicura il supporto all'espletamento dei compiti del Presidente del Consiglio dei ministri, curando, qualora non siano state affidate alle responsabilita' di un ministro senza portafoglio o delegate al sottosegretario di Stato alla Presidenza del consiglio dei ministri, le seguenti funzioni:

- a) predisporre la base conoscitiva e progettuale per l'aggiornamento del programma di Governo;
- b) assicurare il quadro conoscitivo sullo stato di attuazione del programma di Governo, anche mediante il sistema informativo e di documentazione della Presidenza del Consiglio dei ministri in collegamento con i corrispondenti sistemi delle Camere e degli altri organismi pubblici ed avvalendosi dell'attivita' dell'ISTAT;
- c) curare gli adempimenti e predisporre gli atti alla formulazione ed al coordinamento delle iniziative legislative, nonche' all'attuazione della politica istituzionale del Governo;
- d) provvedere alla periodica ricognizione delle disposizioni legislative e regolamentari in vigore anche al fine del coordinamento delle disposizioni medesime;
- e) collaborare alle iniziative concernenti i rapporti tra la Presidenza del Consiglio dei ministri e gli organi dello Stato nonche' predisporre gli elementi di valutazione delle questioni di rilevanza costituzionale;
- f) predisporre gli elementi necessari per la risoluzione delle questioni interessanti la competenza di piu' Ministeri e per assicurare all'azione amministrativa unita' di indirizzo;
- g) curare la raccolta comparativa dei dati sull'andamento della spesa, della finanza pubblica e dell'economia nazionale, ai fini di valutazioni tecniche sulla coerenza economico-finanziaria dell'attivita' di Governo, avvalendosi dell'ISTAT nonche' dei sistemi informativi e dell'apporto di ricerca delle altre amministrazioni e di organismi pubblici;
- h) predisporre gli adempimenti per l'intervento del Governo nella programmazione dei lavori parlamentari e per la proposizione nelle sedi competenti delle priorita' governative, assicurare una costante e tempestiva informazione sui lavori parlamentari anche al fine di coordinare la presenza dei rappresentanti del Governo; provvedere agli adempimenti necessari per l'assegnazione dei disegni di legge alle due Camere, vigilando affinche' il loro esame si armonizzi con la graduale attuazione del programma governativo; curare gli adempimenti inerenti alla presentazione di emendamenti ai progetti di legge all'esame del Parlamento, nonche' gli adempimenti concernenti gli atti del sindacato ispettivo, istruendo quelli rivolti al Presidente del Consiglio e al Governo;
- i) assistere, anche attraverso attivita' di studio e di documentazione, il Presidente del Consiglio dei ministri nella sua attivita' per le relazioni internazionali che intrattiene e, in generale, negli atti di politica estera;
- i-bis) assistere il Presidente del Consiglio dei Ministri nell'esercizio delle sue attribuzioni istituzionali in materia di rapporti con le Confessioni religiose, ferme restando le attribuzioni del Ministero dell'interno di cui all'articolo 14, comma 2, lettera d), del decreto legislativo sul riordinamento dei Ministeri.
- l) assistere il Presidente del Consiglio dei ministri nella sua attivita' per le relazioni con gli organismi che provvedono alla difesa nazionale;
- m) curare il cerimoniale della Presidenza del Consiglio dei ministri;
- n) curare lo studio e l'elaborazione delle modifiche necessarie a conformare la legislazione al fine della uguaglianza tra i sessi ed assistere il Presidente del Consiglio dei ministri in relazione al coordinamento delle amministrazioni competenti nell'attuazione dei progetti nazionali e locali aventi il medesimo fine;
- o) curare gli adempimenti relativi ai modi e ai tempi di applicazione della normativa comunitaria, nonche' la raccolta di dati e informazioni ed il compimento di analisi sulle implicazioni per l'Italia delle politiche comunitarie;
- p) curare gli adempimenti relativi ai rapporti con le regioni e le province autonome di Trento e di Bolzano; all'esame delle leggi regionali ai fini dell'articolo 127 della Costituzione; al coordinamento tra legislazione statale e regionale; all'attivita' dei commissari del Governo nelle regioni; ai problemi delle minoranze linguistiche e dei territori di confine;
- q) mantenere i contatti con gli organi di informazione attraverso il capo dell'ufficio stampa del Presidente del Consiglio dei ministri;
- r) svolgere le attivita' di competenza della Presidenza del Consiglio dei ministri inerenti alla gestione amministrativa del Consiglio di Stato e dei tribunali amministrativi regionali, della Corte dei conti, dell'Avvocatura dello Stato, nonche' degli altri organi ed enti che alla Presidenza del Consiglio dei ministri fanno capo;
- s) curare le attivita' preliminari e successive alle deliberazioni del comitato per la liquidazione delle pensioni privilegiate ordinarie e di ogni altro organo collegiale operante presso la Presidenza del Consiglio dei ministri per disposizione di legge o di regolamento; ((5))
- t) curare gli affari legali e del contenzioso e mantenere i contatti con l'Avvocatura dello Stato;
- u) curare le questioni concernenti il personale della Presidenza del Consiglio dei ministri, nonche' il coordinamento dei servizi amministrativi e tecnici;
- v) ((LETTERA ABROGATA DAL D.LGS 30 LUGLIO 1999, N. 303)).
- z) ((LETTERA ABROGATA DAL D.LGS 30 LUGLIO 1999, N. 303)).
- aa) curare ogni altro adempimento necessario per l'esercizio delle attribuzioni del Presidente del Consiglio dei ministri, del Consiglio dei ministri e dei ministri senza portafoglio;
- bb) assicurare la gestione amministrativa e la manutenzione degli immobili di pertinenza o comunque in uso per le esigenze della Presidenza del Consiglio dei ministri, ivi comprese quelle relative ai dipartimenti e agli uffici affidati alla responsabilita' dei ministri senza portafoglio e dei sottosegretari di Stato alla Presidenza del Consiglio dei ministri, avvalendosi anche delle amministrazioni competenti;
- cc) ((LETTERA ABROGATA DAL D.LGS 30 LUGLIO 1999, N. 303)).

------------- AGGIORNAMENTO (5) Il D.Lgs. 30 luglio 1999, n. 303 ha disposto (con l'art. 12, comma 4, lettera b)) l'abrogazione della lettera s) del comma 1 del presente articolo, per quanto riguarda il riferimento al comitato per la liquidazione delle pensioni privilegiate ordinarie.

### Art. 20. - (Ufficio di segreteria del Consiglio dei ministri)

1. Sono posti alle dirette dipendenze del sottosegretario di Stato alla Presidenza del Consiglio dei ministri l'ufficio di segreteria del Consiglio dei ministri nonche' i dipartimenti ed uffici per i quali il sottosegretario abbia ricevuto delega dal Presidente del Consiglio dei ministri.

2. L'ufficio di segreteria del Consiglio dei ministri assicura la documentazione e l'assistenza necessarie per il Presidente ed i ministri in Consiglio; coadiuva il sottosegretario di Stato alla Presidenza del Consiglio dei ministri, curando gli adempimenti preparatori dei lavori del Consiglio, nonche' quelli di esecuzione delle deliberazioni del Consiglio stesso.

### Art. 21. - (Uffici e dipartimenti)

1. COMMA ABROGATO DAL D.LGS. 30 LUGLIO 1999, N. 303.

2. ((COMMA ABROGATO DAL D.LGS. 31 LUGLIO 2003, N. 226)). ((12))

3. COMMA ABROGATO DAL D.LGS. 30 LUGLIO 1999, N. 303.

4. COMMA ABROGATO DAL D.LGS. 30 LUGLIO 1999, N. 303.

5. COMMA ABROGATO DAL D.LGS. 30 LUGLIO 1999, N. 303.

6. Nei casi in cui un dipartimento della Presidenza del Consiglio dei ministri sia affidato alla responsabilita' di un ministro senza portafoglio, il capo del dipartimento e' nominato con decreto del Presidente del Consiglio dei ministri, su proposta del ministro interessato.

7. Qualora un dipartimento non venga affidato ad un ministro senza portafoglio, il capo del dipartimento dipende dal segretario generale della Presidenza.

------------- AGGIORNAMENTO (12) Il D.Lgs. 31 luglio 2003, n. 226 ha disposto (con l'art. 1, comma 1) che "La Commissione nazionale per la parita' e le pari opportunita' fra uomo e donna, istituita dall'articolo 21, comma 2, della legge 23 agosto 1988, n. 400, e disciplinata dalla legge 22 giugno 1990, n. 164, e' trasformata in organo consultivo e di proposta, denominato Commissione per le pari opportunita' fra uomo e donna, di seguito denominato: "Commissione", presso il Dipartimento per le pari opportunita' della Presidenza del Consiglio dei Ministri".

### Art. 22.

((ARTICOLO ABROGATO DAL D.LGS. 30 LUGLIO 1999, N. 303))

### Art. 23. - (Ufficio centrale per il coordinamento dell'iiziativa legislativa e dell'attivita' normativa del Governo)

1. ((COMMA ABROGATO DAL D.LGS. 30 LUGLIO 1999, N. 303)).

2. Per ciascuna legge o atto avente valore di legge e per ciascun regolamento pubblicati nella Gazzetta Ufficiale l'Ufficio segnala al Presidente del Consiglio dei ministri, ai fini della pubblicazione nella Gazzetta Ufficiale, le disposizioni abrogate o direttamente modificate per effetto delle nuove disposizioni di legge o di regolamento.

3. L'Ufficio indica in rapporti periodici al Presidente del Consiglio dei ministri e ai ministri interessati incongruenze e antinomie normative relative ai diversi settori legislativi; segnale la necessita' di procedere alla codificazione della disciplina di materie o alla redazione di testi unici. Tali rapporti vengono inviati, a cura della Presidenza del Consiglio dei ministri, alla Presidenza della Camera dei deputati e alla Presidenza del Senato della Repubblica.

4. In relazione a testi normativi di particolare rilevanza l'Ufficio provvede a redigere il testo coordinato della legge e del regolamento vigenti.

5. Le indicazioni fornite e i testi redatti dall'Ufficio hanno funzione esclusivamente conoscitiva e non modificano il valore degli atti normativi che ne sono oggetto.

6. Il decreto del Presidente della Repubblica di cui al comma 1 regolamenta l'organizzazione e l'attivita' dell'Ufficio prevedendo la possibilita' che questo si avvalga di altri organi della pubblica amministrazione e promuova forme di collaborazione con gli uffici delle presidenze delle giunte regionali al fine di armonizzare i testi normativi statali e regionali.

7. All'Ufficio e' proposto un magistrato delle giurisdizioni superiori, ordinaria o amministrativa, ovvero un dirigente generale dello Stato o un avvocato dello Stato o un professore universitario di ruolo di discipline giuridiche.

### Art. 24. - (Delega per la riforma degli enti pubblici di informazione statistica)

1. Il Governo e' delegato ad emanare, entro un anno dalla data di entrata in vigore della presente legge, norme aventi valore di legge ordinaria per la riforma degli enti e degli organismi pubblici di informazione statistica in base ai seguenti principi e criteri direttivi:

- a) che sia attuato il sistematico collegamento e l'interconnessione di tutte le fonti pubbliche proposte alla raccolta e alla elaborazione dei dati statistici a livello centrale e locale;
- b) che sia istituito un ufficio di statistica presso ogni amministrazione centrale dello Stato, incluse le aziende autonome, e che gli uffici cosi' istituiti siano posti alle dipendenze funzionali dell'ISTAT;
- c) che siano attribuiti all'ISTAT i compiti di indirizzo e coordinamento;
- d) che sia garantito il principio dell'imparzialita' e della completezza nella raccolta, nella elaborazione e nella diffusione dei dati;
- e) che sia garantito l'acceso diretto da parte del Parlamento, delle regioni, di enti pubblici, di organi dello Stato, di persone giuridiche di associazioni e singoli cittadini ai dati elaborati con i limiti espressamente previsti dalla legge e nel rispetto dei diritti fondamentali della persona;
- f) che sia informato annualmente il Parlamento sull'attivita' dell'ISTAT, sulla raccolta, trattamento e diffusione dei dati statistici da parte della pubblica amministrazione;
- g) che sia garantita l'autonomia dell'ISTAT in materia di strutture, di organizzazione e di risorse finanziarie.

2. I decreti delegati di cui al comma 1 sono emanati previo parere delle Commissioni permanenti delle Camere competenti per materia. Il Governo procede comunque alla emanazione dei decreti delegati qualora tale parere non sia espresso entro sessanta giorni dalla richiesta.

### Art. 25. - (Vigilanza su enti ed istituzioni)

1. Le funzioni di vigilanza su enti pubblici ed istituzioni le cui funzioni istituzionali non siano considerate coerenti con le competenze proprie della Presidenza del Consiglio dei ministri, e che siano attribuite alla Presidenza del Consiglio medesima da leggi, regolamenti o statuti, sono trasferite ai ministri che saranno individuati, in relazione agli specifici settori di competenza, con decreti del Presidente della Repubblica, adottati su proposta del Presidente del Consiglio dei ministri, da emanarsi entro sei mesi dalla data di entrata in vigore della presente legge.

2. La funzione di vigilanza sul Consiglio delle ricerche e' attribuita al ministro competente a presentare al Parlamento la relazione sullo stato della ricerca scientifica.

### Art. 26. - (Dipartimento per l'informazione e l'editoria)

1. Nell'ambito del Segretariato generale della Presidenza del Consiglio dei ministri e' istituito il dipartimento per l'informazione e l'editoria, che sostituisce la direzione generale delle informazioni, dell'editoria e della proprieta' letteraria, artistica e scientifica e subentra nell'esercizio delle funzioni a questa spettanti.

2. All'organizzazione del dipartimento si provvede in conformita' al coma 3 dell'articolo 21.

3. Il relativo ruolo del personale si aggiunge a quello della Presidenza del Consiglio dei ministri.

((

3-bis. Il dipartimento, nei limiti delle disponibilita' derivanti dall'applicazione del comma 3-ter, realizza e promuove campagne informative attraverso la televisione, la radio, il cinema e la stampa quotidiana e periodica, volte a sensibilizzare l'opinione pubblica sulla illiceita' dell'acquisto di prodotti delle opere dell'ingegno abusivi o contraffatti

3-ter. Per le finalita' di cui al comma 3-bis sono utilizzate le somme affluite nel capitolo di cui all'articolo 174-bis, comma 2, lettera b), della legge 22 aprile 1941, n. 633, e successive modificazioni))

### Art. 27.

((ARTICOLO ABROGATO DAL D.LGS. 30 LUGLIO 1999, N. 303))

### Art. 28. - (Capi dei dipartimenti e degli uffici)

1. I capi dei dipartimenti e degli uffici di cui all'articolo 21 nonche' dell'ufficio di segreteria del Consiglio dei ministri sono nominati con decreto del Presidente del Consiglio dei ministri (( tra le categorie di personale di cui all'art. 18 comma 2.))

### Art. 29. - (Consulenti e comitati di consulenza)

1. Il Presidente del Consiglio dei ministri puo' avvalersi di consulenti e costituire comitati, di ricerca o di studio su specifiche questioni.

2. Per tali attivita' si provvede con incarichi a tempo determinato da conferire a magistrati, docenti universitari, avvocati dello Stato, dirigenti e altri dipendenti delle amministrazioni dello Stato, degli enti pubblici, anche economici, delle aziende a prevalente partecipazione pubblica o anche ad esperti estranei all'amministrazione dello Stato.

3. ((COMMA ABROGATO DAL D.LGS. 30 LUGLIO 1999, N. 303)). ((5))

------------- AGGIORNAMENTO (5) Il D.Lgs. 30 luglio 1999, n. 303 ha disposto (con l'art. 12, comma 5) che l'abrogazione del comma 3 del presente articolo "ha effetto dalla data di emanazione degli atti del Presidente che fissano i criteri e limiti di cui all'articolo 9, comma 2, ed il contingente di cui al comma 5 del medesimo articolo 9".

## PERSONALE DELLA PRESIDENZA DEL CONSIGLIO DEI MINISTRI

### Art. 30.

((ARTICOLO ABROGATO DAL D.LGS. 30 LUGLIO 1999, N. 303))

### Art. 31. - (Consiglieri ed esperti)

1. ((COMMA ABROGATO DAL D.LGS. 30 LUGLIO 1999, N. 303)). ((5))

2. ((COMMA ABROGATO DAL D.LGS. 30 LUGLIO 1999, N. 303)). ((5))

3. ((COMMA ABROGATO DAL D.LGS. 30 LUGLIO 1999, N. 303)). ((5))

4. I decreti di conferimento di incarico ad esperti nonche' quelli relativi a dipendenti di amministrazioni pubbliche diverse dalla Presidenza del Consiglio dei ministri o di enti pubblici, con qualifica dirigenziale equiparata, in posizione di fuori ruolo o di comando, ove non siano confermati entro tre mesi dal giuramento del Governo, cessano di avere effetto.

5. ((COMMA ABROGATO DAL D.LGS. 30 LUGLIO 1999, N. 303)). ((5))

------------- AGGIORNAMENTO (5) Il D.Lgs. 30 luglio 1999, n. 303 ha disposto (con l'art. 12, comma 5) che l'abrogazione del commi 1, 2, 3 e 5 del presente articolo "ha effetto dalla data di emanazione degli atti del Presidente che fissano i criteri e limiti di cui all'articolo 9, comma 2, ed il contingente di cui al comma 5 del medesimo articolo 9".

### Art. 32. - (Trattamento economico del personale della Presidenza del Consiglio dei ministri)

1. L'indennita' di cui all'articolo 8 della legge 8 agosto 1985, n. 455, spetta al personale in ruolo della Presidenza del Consiglio dei ministri.

2. I dipendenti da amministrazioni diverse dalla Presidenza del Consiglio dei ministri ed in servizio presso di essa in posizione di comando o fuori ruolo conservano il trattamento economico dell'amministrazione di appartenenza e ad essi viene attribuita una indennita' mensile non pensionabile stabilita con decreto del Presidente del Consiglio dei ministri d'intesa con il ministro del tesoro ai fini di perequazione del rispettivo trattamento economico complessivo con quello spettante al personale di qualifica pari od equiparata di cui al comma 1. Tale indennita', spettante anche al personale dei Gabinetti e delle segreterie particolari dei ministri senza portafoglio e dei sottosegretari di Stato presso la Presidenza del Consiglio dei ministri non puo' comunque superare il limite massimo previsto dall'articolo 8, comma 1, della legge 8 agosto 1985, n. 455, e ad essa si applicano le disposizioni di cui ai commi 2 e 3 del medesimo articolo.

3. Il Presidente del Consiglio dei ministri determina con proprio decreto, di concerto con il ministro del tesoro, gli uffici ed i dipartimenti della Presidenza del Consiglio dei ministri cui si applicano i criteri di attribuzione di ore di lavoro straordinario di cui all'articolo 19 della legge 15 novembre 1973, n. 734.

4. Il compenso degli esperti, dei consiglieri a tempo parziale e del personale incaricato di cui alle tabelle A e B, allegate alla presente legge, nonche' dei componenti del comitato di cui all'articolo 21, comma 1, e' determinato con decreti del Presidente del Consiglio dei ministri d'intesa con il ministro del tesoro.

### Art. 33. - (Personale dei corpi di polizia assegnato alla Presidenza del Consiglio dei ministri)

1. Con decreto del Presidente del Consiglio dei ministri adottato di concerto con i ministri dell'interno e del tesoro, viene fissato il contingente del personale appartenente ai corpi di polizia assegnato alla Presidenza del Consiglio dei ministri per l'assolvimento di compiti connessi a quelli d'istituto dei corpi di provenienza.

2. I posti nei rispettivi corpi di appartenenza resisi vacanti a seguito della destinazione alla Presidenza del Consiglio dei ministri prevista dal comma 1 sono considerati disponibili per nuove nomine.

3. La restituzione del personale di cui al presente articolo al corpo di appartenenza avviene, ove necessario, anche in soprannumero, salvo successivo riassorbimento.

### Art. 34. - (Oneri relativi al personale a disposizione della Presidenza del Consiglio dei ministri ed agli uffici dei commissari del Governo nelle regioni)

1. Le amministrazioni e gli enti di appartenenza continuano a corrispondere gli emolumenti al proprio personale posto a disposizione della Presidenza del Consiglio dei ministri. La Presidenza del Consiglio dei ministri provvede a rimborsare i relativi oneri nei riguardi delle amministrazioni dello Stato ad ordinamento autonomo e delle amministrazioni pubbliche non statali e assume a proprio carico le spese relative alla dotazione degli immobili da destinare a sede dei commissari del Governo nelle regioni.

### Art. 35.

((ARTICOLO ABROGATO DAL D.LGS. 30 LUGLIO 1999, N. 303))

### Art. 36. - (Stato giuridico del personale amministrativo della Presidenza del Consiglio dei ministri)

1. Per quanto non diversamente disposto dalla presente legge, al personale amministrativo della Presidenza del Consiglio dei ministri si applicano le norme relative ai dipendenti civili dello Stato.

2. Al predetto personale, proveniente da amministrazioni pubbliche non statali e da enti pubblici anche economici, e' data facolta' di optare per il mantenimento della posizione assicurativa gia' costituita nell'ambito dell'assicurazione generale obbligatoria, delle forme sostitutive o esclusive dell'amministrazione stessa e degli eventuali fondi di previdenza esistenti presso le amministrazioni di provenienza.

### Art. 37.

((ARTICOLO ABROGATO DAL D.LGS. 30 LUGLIO 1999, N. 303)) ((5))

------------- AGGIORNAMENTO (5) Il D.Lgs. 30 luglio 1999, n. 303 ha disposto (con l'art. 12, comma 5) che l'abrogazione del comma 2 del presente articolo "ha effetto dalla data di emanazione degli atti del Presidente che fissano i criteri e limiti di cui all'articolo 9, comma 2, ed il contingente di cui al comma 5 del medesimo articolo 9".

### Art. 38. - (Norme per la copertura dei posti)

1. Il personale con qualifica di dirigente generale, livello B e C, ed equiparata, di dirigente superiore e di primo dirigente, in servizio presso la Presidenza del Consiglio dei ministri alla data di entrata in vigore della presente legge, e' inquadrato a domanda, nei limiti della meta' dei posti in ruolo indicati nella tabella A, nelle qualifiche corrispondenti del ruolo dei consiglieri della Presidenza del Consiglio dei ministri.

2. In sede di prima applicazione della presente legge, l'accesso alla qualifica di primo dirigente, nel limite del 25 per cento dei posti di cui all'allegata tabella A, avviene mediante il concorso speciale per esami previsto dall'articolo 2 della legge 10 luglio 1984, n. 301, e secondo le modalita' ivi stabilite, al quale sono ammessi, a domanda, gli impiegati in servizio presso la Presidenza del Consiglio dei ministri in possesso di laurea inquadrati nelle qualifiche settima e superiori, nonche' quelli con qualifiche di ispettore generale e di direttore di divisione del ruolo ad esaurimento, purche' alla data di entrata in vigore della presente legge gli aventi titolo a partecipare al concorso abbiamo maturato almeno nove anni di servizio effettivo nella carriera direttiva.

3. Il personale delle qualifiche funzionali e di quelle ad esaurimento, comunque in servizio alla data di entrata in vigore della presente legge presso la Presidenza del Consiglio dei ministri in posizione di comando o fuori ruolo, viene inquadrato a domanda nelle qualifiche corrispondenti del personale in ruolo della Presidenza del Consiglio dei ministri nei limiti dei posti della tabella B disponibili.

4. Il personale di cui al comma 3 puo' chiedere di essere inquadrato, anche in soprannumero e previo superamento di esame-colloquio, nella qualifica funzionale della carriera immediatamente superiore, con il profilo professionale corrispondente alle mansioni superiori lodevolmente esercitate per almeno due anni, purche' in possesso del titolo di studio richiesto per l'accesso alla nuova qualifica ovvero, ad esclusione della carriera direttiva, di un'anzianita' di servizio effettivo non inferiore a dieci anni. Tale beneficio non potra' comunque essere attribuito al personale che, per effetto di norme analoghe, a quella prevista nel presente comma, abbia comunque fruito, anche presso le Amministrazioni di appartenenza, di avanzamenti di carriera o promozioni a qualifiche superiori, disposti a seguito di valutazione delle mansioni svolte.

5. Le domande di cui ai commi 1, 3 e 4 debbono essere presentate entro il termine perentorio di trenta giorni dalla data di entrata in vigore della presente legge.

6. Alle operazioni di inquadramento di cui ai commi 1 e 3, che debbono essere ultimate entro quindici mesi dalla data di entrata in vigore della presente legge, provvede una commissione nominata dal Presidente del Consiglio dei ministri e presieduta dal sottosegretario di Stato alla Presidenza del Consiglio dei ministri o, per sua delega, da un magistrato amministrativo con qualifica di Presidente di Sezione del Consiglio di Stato o equiparata e composta da quattro membri effettivi e quattro supplenti di qualifica non inferiore al personale da inquadrare o docenti universitari di diritto pubblico. Tale commissione individua gli aventi diritto all'inquadramento, in relazione ai posti disponibili, a seguito della valutazione, da effettuarsi in base a criteri oggettivi predeterminati dalla commissione stessa, dei titoli culturali, professionali e di merito, con particolare riguardo alla qualita' del servizio prestato, alla durata del periodo di effettivo servizio presso la Presidenza del Consiglio dei ministri nonche' all'anzianita' maturata presso le amministrazioni e gli enti di provenienza.

7. Al personale di cui ai commi 3 e 4 si applicano le disposizioni previste nei commi 3 e 4 dell'articolo 2 della legge 8 agosto 1985, n. 455.

8. I posti delle qualifiche funzionali rimasti disponibili dopo le operazioni di inquadramento, e quelli che tali si renderanno nei cinque anni successivi alla data di entrata in vigore della presente legge, sono conferiti mediante concorso per titoli ed esame-colloquio riservato al personale comunque in servizio presso la Presidenza del Consiglio dei ministri in possesso dei requisiti di cui all'articolo 14, commi secondo e terzo, della legge 11 luglio 1980, n. 312. Con decreto del Presidente del Consiglio dei ministri sono determinate, distintamente per le categorie interessate, le materie dell'esame-colloquio e le modalita' di partecipazione e di svolgimento del concorso.

9. Ai fini di quanto previsto dai commi 3, 6 e 8 si considerano indisponibili i posti da conferire mediante i concorsi di cui all'articolo 6 della legge 8 agosto 1985, n. 455.

10. Il personale che abbia presentato domanda di inquadramento ai sensi dei commi 1, 3 e 4 continua a prestare servizio presso la Presidenza del Consiglio dei ministri anche nel periodo compreso tra la data di entrata in vigore della presente legge e la conclusione del procedimento di inquadramento. Nello stesso periodo resta fermo per tale personale quanto previsto dall'articolo 8 della legge 8 agosto 1985, n. 455.

11. Nella prima attuazione della presente legge, al fine di far fronte alle vacanze eventualmente esistenti nei posti in ruolo della Presidenza del Consiglio dei ministri, potra' essere chiamato personale di altre amministrazioni in posizione di comando o fuori ruolo anche in eccedenza ai limiti relativi a dette posizioni previsti dalle allegate tabelle, nel numero massimo stabilito con decreto del Presidente del Consiglio dei ministri di concerto con il ministro del tesoro.

12. Per lo svolgimento delle funzioni previste dall'articolo 27 della legge 29 marzo 1983, n. 93, la Presidenza del Consiglio dei ministri si avvale del personale dirigente e di quello delle qualifiche ad esaurimento e funzionali in servizio presso il Dipartimento della funzione pubblica, nei limiti dei contingenti numerici di cui ai quadri A, B e C della tabella allegata al decreto del Presidente della Repubblica 20 giugno 1984, n. 536. I contingenti numerici di cui ai quadri B e C della predetta tabella si aggiungono in ragione di due terzi alle posizioni di ruolo organico di cui alle tabelle A e B, allegate alla presente legge, e del restante terzo alle posizioni di comando e di fuori ruolo di cui alle tabelle stesse.

13. Il personale assunto entro la data del 31 agosto 1987, ai sensi dell'articolo 36 della legge 28 febbraio 1986, n. 41, ed in servizio alla medesima data, e' collocato a domanda nelle categorie del personale non di ruolo previste dalla tabella 1 allegata al regio decreto-legge 4 febbraio 1937, n. 100, e successive modifiche ed integrazioni. Con decreto del Presidente del Consiglio dei ministri, di concerto con il ministro del tesoro, sono emanate disposizioni per l'inquadramento in ruolo del predetto personale.

### Art. 39.

((ARTICOLO ABROGATO DAL D.LGS. 30 LUGLIO 1999, N. 303))

## NORME FINALI E FINANZIARIE

### Art. 40. - (Norme finali)

1. Fino a quando non saranno emanati i decreti di cui al comma 5 dell'articolo 21, restano ferme le disposizioni vigenti relative alla organizzazione di uffici cui siano preposti ministri senza portafoglio.

2. Per la segreteria particolare del Presidente del Consiglio dei ministri, per i Gabinetti e le segreterie particolari del Vicepresidente del Consiglio dei ministri e dei ministri senza portafoglio, nonche' per la segreteria particolare del sottosegretario di Stato alla Presidenza del Consiglio dei ministri, si applicano le disposizioni vigenti.

3. Sono abrogate le norme contenute nel regio decreto-legge 10 luglio 1924, n. 1100, e successive modificazioni ed integrazioni, riguardanti la costituzione e la disciplina del gabinetto della Presidenza del Consiglio dei ministri.

4. Sono soppressi i profili professionali e la distinzione in ruoli di cui alla tabella allegata alla legge 8 agosto 1985, n. 455.

5. Si considerano indisponibili i posti da conferire mediante i concorsi di cui all'articolo 6 della legge 8 agosto 1985, n. 455.

### Art. 41. - (Disposizioni finanziarie)

1. L'onere derivante dalla attuazione della presente legge, nonche' dell'articolo 8 della legge 8 agosto 1985, n. 455, ivi compresa l'applicazione di quest'ultima legge al personale comunque in servizio presso gli uffici dei ministri senza portafoglio, presso il comitato per le pensioni privilegiate ordinarie e presso i commissari del Governo, e' valutato in lire 6.000 milioni per l'anno 1988 ed in lire 35.050 milioni per gli anni 1989 e 1990. Alla spesa relativa si provvede, quanto a lire 6.000 milioni per l'anno 1988 ed a lire 34.750 milioni per ciascuno degli anni 1989 e 1990, mediante corrispondente riduzione dello stanziamento iscritto, ai fini del bilancio triennale 1988-1990, al capitolo 6856 dello stato di previsione del Ministero del tesoro per l'anno finanziario 1988, all'uopo utilizzando lo specifico accantonamento "Disciplina dell'attivita' di Governo ed ordinamento della Presidenza del Consiglio dei ministri", e, quanto a lire 300 milioni per ciascuno degli anni 1989 e 1990, mediante utilizzo delle proiezioni per gli anni medesimi dell'accantonamento "Riforma del processo amministrativo" iscritto, ai fini del bilancio triennale 1988-1990, al predetto capitolo 6856 dello stato di previsione del Ministero del tesoro per il 1988.

2. Contestualmente agli inquadramenti del personale delle amministrazioni dello Stato, anche ad ordinamento autonomo, nel ruolo di cui alle allegate tabelle, il ministro del tesoro e' autorizzato a stornare con propri decreti dai competenti capitoli degli stati di previsione delle amministrazioni di provenienza ai pertinenti capitoli dello stato di previsione della Presidenza del Consiglio dei ministri gli importi relativi agli stipendi ed altri assegni fissi in godimento di ciascun dipendente interessato dall'inquadramento.

3. Il Ministro del tesoro e' autorizzato ad apportare, con propri decreti, le occorrenti variazioni di bilancio.

